summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:36:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:36:08 -0600
commitc3b301575a98e4c3505ad95534d6192b65539dab (patch)
tree532456654ca955508c4a6e7cd6f04db4ce151c53 /lib
parent1623fe64102c18ab098b79656b80f28cef840756 (diff)
downloadtdevelop-c3b301575a98e4c3505ad95534d6192b65539dab.tar.gz
tdevelop-c3b301575a98e4c3505ad95534d6192b65539dab.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'lib')
-rw-r--r--lib/catalog/tag.h2
-rw-r--r--lib/cppparser/ast.cpp2
-rw-r--r--lib/cppparser/lexer.cpp6
-rw-r--r--lib/cppparser/lexercache.cpp6
-rw-r--r--lib/cppparser/lexercache.h2
-rw-r--r--lib/interfaces/extensions/kdevcreatefile.h4
-rw-r--r--lib/interfaces/extensions/kdevversioncontrol.h6
-rw-r--r--lib/interfaces/external/designer.h2
-rw-r--r--lib/util/blockingkprocess.cpp4
-rw-r--r--lib/util/filetemplate.cpp4
-rw-r--r--lib/util/settings.cpp6
-rw-r--r--lib/widgets/flagboxes.cpp2
-rw-r--r--lib/widgets/processwidget.cpp6
-rw-r--r--lib/widgets/processwidget.h2
-rw-r--r--lib/widgets/propeditor/pcheckbox.cpp2
-rw-r--r--lib/widgets/propeditor/pcolorbutton.cpp2
-rw-r--r--lib/widgets/propeditor/pcolorcombo.cpp2
-rw-r--r--lib/widgets/propeditor/pcombobox.cpp2
-rw-r--r--lib/widgets/propeditor/pdateedit.cpp2
-rw-r--r--lib/widgets/propeditor/pdatetimeedit.cpp2
-rw-r--r--lib/widgets/propeditor/pdoublenuminput.cpp2
-rw-r--r--lib/widgets/propeditor/pfontbutton.cpp2
-rw-r--r--lib/widgets/propeditor/pfontcombo.cpp2
-rw-r--r--lib/widgets/propeditor/plineedit.cpp2
-rw-r--r--lib/widgets/propeditor/plinestyleedit.cpp2
-rw-r--r--lib/widgets/propeditor/ppixmapedit.cpp4
-rw-r--r--lib/widgets/propeditor/ppointedit.cpp2
-rw-r--r--lib/widgets/propeditor/prectedit.cpp2
-rw-r--r--lib/widgets/propeditor/propertyeditor.cpp8
-rw-r--r--lib/widgets/propeditor/psizeedit.cpp2
-rw-r--r--lib/widgets/propeditor/psizepolicyedit.cpp2
-rw-r--r--lib/widgets/propeditor/pspinbox.cpp2
-rw-r--r--lib/widgets/propeditor/pstringlistedit.cpp4
-rw-r--r--lib/widgets/propeditor/psymbolcombo.cpp4
-rw-r--r--lib/widgets/propeditor/purledit.cpp2
-rw-r--r--lib/widgets/propeditor/pyesnobutton.cpp2
-rw-r--r--lib/widgets/propeditor/qeditlistbox.cpp2
-rw-r--r--lib/widgets/qcomboview.cpp48
-rw-r--r--lib/widgets/qcomboview.h2
39 files changed, 81 insertions, 81 deletions
diff --git a/lib/catalog/tag.h b/lib/catalog/tag.h
index 95604c83..a3f7711b 100644
--- a/lib/catalog/tag.h
+++ b/lib/catalog/tag.h
@@ -122,7 +122,7 @@ public:
data->fileName = fileName;
}
- TQString path( const TQString& sep = TQString::tqfromLatin1("::") ) const
+ TQString path( const TQString& sep = TQString::fromLatin1("::") ) const
{
TQString s = scope().join( sep );
if( s.isNull() )
diff --git a/lib/cppparser/ast.cpp b/lib/cppparser/ast.cpp
index e4e3cf5d..326ee625 100644
--- a/lib/cppparser/ast.cpp
+++ b/lib/cppparser/ast.cpp
@@ -474,7 +474,7 @@ TQString ClassOrNamespaceNameAST::text() const
TQString str = m_name->text();
if( m_templateArgumentList.get() )
- str += TQString::tqfromLatin1("< ") + m_templateArgumentList->text() + TQString::tqfromLatin1(" >");
+ str += TQString::fromLatin1("< ") + m_templateArgumentList->text() + TQString::fromLatin1(" >");
return str;
}
diff --git a/lib/cppparser/lexer.cpp b/lib/cppparser/lexer.cpp
index 1ed9fca7..c19408e6 100644
--- a/lib/cppparser/lexer.cpp
+++ b/lib/cppparser/lexer.cpp
@@ -393,14 +393,14 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
}
if( stringify ) {
- textToInsert.append( TQString::tqfromLatin1("\"") + str.str() + TQString::tqfromLatin1("\" ") );
+ textToInsert.append( TQString::fromLatin1("\"") + str.str() + TQString::fromLatin1("\" ") );
} else if( merge ){
textToInsert.truncate( textToInsert.length() - 1 );
- textToInsert.append( str.str() + TQString::tqfromLatin1(" ") );
+ textToInsert.append( str.str() + TQString::fromLatin1(" ") );
} else if( tok == Token_ellipsis && d->hasBind("...") ){
textToInsert.append( ellipsisArg );
} else {
- textToInsert.append( str.str() + TQString::tqfromLatin1(" ") );
+ textToInsert.append( str.str() + TQString::fromLatin1(" ") );
}
}
diff --git a/lib/cppparser/lexercache.cpp b/lib/cppparser/lexercache.cpp
index 7f420cac..cbe8640d 100644
--- a/lib/cppparser/lexercache.cpp
+++ b/lib/cppparser/lexercache.cpp
@@ -112,13 +112,13 @@ TQDateTime LexerCache::fileModificationTimeCached( const HashedString& fileName
FileModificationMap::const_iterator it = m_fileModificationCache.find( fileName );
if( it != m_fileModificationCache.end() ) {
///Use the cache for 10 seconds
- if( (*it).second.m_readTime.secsTo( m_tqcurrentDateTime ) < 10 ) {
+ if( (*it).second.m_readTime.secsTo( m_currentDateTime ) < 10 ) {
return (*it).second.m_modificationTime;
}
}
TQFileInfo fileInfo( fileName.str() );
- m_fileModificationCache[fileName].m_readTime = TQDateTime::tqcurrentDateTime();
+ m_fileModificationCache[fileName].m_readTime = TQDateTime::currentDateTime();
m_fileModificationCache[fileName].m_modificationTime = fileInfo.lastModified();
return fileInfo.lastModified();
@@ -239,7 +239,7 @@ size_t CachedLexedFile::hash() const {
}
void LexerCache::initFileModificationCache() {
- m_tqcurrentDateTime = TQDateTime::tqcurrentDateTime();
+ m_currentDateTime = TQDateTime::currentDateTime();
}
void LexerCache::saveMemory() {
diff --git a/lib/cppparser/lexercache.h b/lib/cppparser/lexercache.h
index 535768bc..c1aac432 100644
--- a/lib/cppparser/lexercache.h
+++ b/lib/cppparser/lexercache.h
@@ -155,7 +155,7 @@ class LexerCache : public CacheManager {
typedef __gnu_cxx::hash_map<HashedString, FileModificationCache> FileModificationMap;
FileModificationMap m_fileModificationCache;
Driver* m_driver;
- TQDateTime m_tqcurrentDateTime;
+ TQDateTime m_currentDateTime;
};
diff --git a/lib/interfaces/extensions/kdevcreatefile.h b/lib/interfaces/extensions/kdevcreatefile.h
index ee30f555..76dff18b 100644
--- a/lib/interfaces/extensions/kdevcreatefile.h
+++ b/lib/interfaces/extensions/kdevcreatefile.h
@@ -54,7 +54,7 @@ public:
public:
/**The status of a file.*/
- enum tqStatus {
+ enum Status {
STATUS_OK /**<File was successfuly created.*/,
STATUS_CANCELED /**<File was not created due to user intervention.*/,
STATUS_NOTCREATED /**<File was not created due to error.*/,
@@ -105,7 +105,7 @@ public:
there are several file templates for each extension.*/
TQString subtype;
/**Current status.*/
- tqStatus status;
+ Status status;
/**true if the file should be added to a project.*/
bool addToProject;
};
diff --git a/lib/interfaces/extensions/kdevversioncontrol.h b/lib/interfaces/extensions/kdevversioncontrol.h
index 2dcfe869..01fc6115 100644
--- a/lib/interfaces/extensions/kdevversioncontrol.h
+++ b/lib/interfaces/extensions/kdevversioncontrol.h
@@ -198,7 +198,7 @@ public:
This is a <b>synchronous operation</b> (blocking).
@param dirPath The relative (to project dir) directory path to stat.
- @return tqStatus for all <b>registered</b> files.*/
+ @return Status for all <b>registered</b> files.*/
virtual const VCSFileInfoMap *status(const TQString &dirPath) = 0;
/**Starts a request for directory status to the remote repository.
@@ -214,14 +214,14 @@ public:
@param checkRepos If true, contact remote repository and augment repository's status.
If false, retrieve only for local modification information.
@return true if the request has been successfully started, false otherwise.*/
- virtual bool requesttqStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true ) = 0;
+ virtual bool requestStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true ) = 0;
signals:
/**Emitted when the status request to remote repository has finished.
@param fileInfoMap The status for <b>registered in repository</b> files.
@param callerData The pointer to some data you want the provider will return
to you when it has done
- @see requesttqStatus for to find out when this signal should be used.*/
+ @see requestStatus for to find out when this signal should be used.*/
void statusReady(const VCSFileInfoMap &fileInfoMap, void *callerData);
protected:
diff --git a/lib/interfaces/external/designer.h b/lib/interfaces/external/designer.h
index 9f0c0064..c071f2db 100644
--- a/lib/interfaces/external/designer.h
+++ b/lib/interfaces/external/designer.h
@@ -91,7 +91,7 @@ signals:
/**Emitted when a form state is changed in the designer.
@param formName An absolute name of the form file.
@param status 0: form is clean, 1: form is modified.*/
- void newtqStatus(const TQString &formName, int status);
+ void newStatus(const TQString &formName, int status);
};
}
diff --git a/lib/util/blockingkprocess.cpp b/lib/util/blockingkprocess.cpp
index 51845a5c..c0d1b106 100644
--- a/lib/util/blockingkprocess.cpp
+++ b/lib/util/blockingkprocess.cpp
@@ -68,12 +68,12 @@ bool BlockingKProcess::start(RunMode runmode, Communication comm)
void BlockingKProcess::slotReceivedStdOut(KProcess *, char *buffer, int buflen)
{
- m_stdOut += TQString::tqfromLatin1(buffer, buflen);
+ m_stdOut += TQString::fromLatin1(buffer, buflen);
}
void BlockingKProcess::slotReceivedStdErr(KProcess *, char *buffer, int buflen)
{
- m_stdErr += TQString::tqfromLatin1(buffer, buflen);
+ m_stdErr += TQString::fromLatin1(buffer, buflen);
}
void BlockingKProcess::slotProcessExited(KProcess *)
diff --git a/lib/util/filetemplate.cpp b/lib/util/filetemplate.cpp
index e0425614..ac4b018c 100644
--- a/lib/util/filetemplate.cpp
+++ b/lib/util/filetemplate.cpp
@@ -69,8 +69,8 @@ TQString FileTemplate::makeSubstitutions( TQDomDocument & dom, const TQString &
TQString email = DomUtil::readEntry(dom, "/general/email");
TQString version = DomUtil::readEntry(dom, "/general/version");
TQString appname = DomUtil::readEntry(dom, "/general/projectname");
- TQString date = TQDate::tqcurrentDate().toString();
- TQString year = TQString::number(TQDate::tqcurrentDate().year());
+ TQString date = TQDate::currentDate().toString();
+ TQString year = TQString::number(TQDate::currentDate().year());
TQString str = text;
str.replace(TQRegExp("\\$EMAIL\\$"),email);
diff --git a/lib/util/settings.cpp b/lib/util/settings.cpp
index f91c91f0..c9087942 100644
--- a/lib/util/settings.cpp
+++ b/lib/util/settings.cpp
@@ -23,12 +23,12 @@ TQString Settings::terminalEmulatorName( KConfig & config )
if ( useKDESetting )
{
- KConfigGroup confGroup( KGlobal::config(), TQString::tqfromLatin1("General") );
- terminal = confGroup.readEntry("TerminalApplication", TQString::tqfromLatin1("konsole"));
+ KConfigGroup confGroup( KGlobal::config(), TQString::fromLatin1("General") );
+ terminal = confGroup.readEntry("TerminalApplication", TQString::fromLatin1("konsole"));
}
else
{
- terminal = config.readEntry( "TerminalApplication", TQString::tqfromLatin1("konsole"));
+ terminal = config.readEntry( "TerminalApplication", TQString::fromLatin1("konsole"));
}
return terminal;
}
diff --git a/lib/widgets/flagboxes.cpp b/lib/widgets/flagboxes.cpp
index 038d7936..a9a35069 100644
--- a/lib/widgets/flagboxes.cpp
+++ b/lib/widgets/flagboxes.cpp
@@ -72,7 +72,7 @@ void FlagListToolTip::maybeTip(const TQPoint &pos)
FlagListItem *flitem = static_cast<FlagListItem*>(item);
if (item)
- tip(listbox->tqitemRect(item), flitem->desc);
+ tip(listbox->itemRect(item), flitem->desc);
}
diff --git a/lib/widgets/processwidget.h b/lib/widgets/processwidget.h
index 5c33dd86..814db870 100644
--- a/lib/widgets/processwidget.h
+++ b/lib/widgets/processwidget.h
@@ -109,7 +109,7 @@ signals:
void rowSelected(int row);
protected:
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize minimumSizeHint() const;
void maybeScrollToBottom();
protected slots:
diff --git a/lib/widgets/propeditor/pcheckbox.cpp b/lib/widgets/propeditor/pcheckbox.cpp
index 4a12d575..f3bd2673 100644
--- a/lib/widgets/propeditor/pcheckbox.cpp
+++ b/lib/widgets/propeditor/pcheckbox.cpp
@@ -36,7 +36,7 @@ PCheckBox::PCheckBox(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQCheckBox(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(updateProperty(bool)));
diff --git a/lib/widgets/propeditor/pcolorbutton.cpp b/lib/widgets/propeditor/pcolorbutton.cpp
index bb927a08..4b6ae5c4 100644
--- a/lib/widgets/propeditor/pcolorbutton.cpp
+++ b/lib/widgets/propeditor/pcolorbutton.cpp
@@ -45,7 +45,7 @@ PColorButton::PColorButton(MultiProperty* property, TQWidget* parent, const char
connect(m_edit, TQT_SIGNAL(clicked()), this, TQT_SLOT(changeColor()));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
}
diff --git a/lib/widgets/propeditor/pcolorcombo.cpp b/lib/widgets/propeditor/pcolorcombo.cpp
index b0c82de3..23c61f46 100644
--- a/lib/widgets/propeditor/pcolorcombo.cpp
+++ b/lib/widgets/propeditor/pcolorcombo.cpp
@@ -31,7 +31,7 @@ PColorCombo::PColorCombo(MultiProperty *property, TQWidget *parent, const char *
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KColorCombo(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(activated(int)), this, TQT_SLOT(updateProperty(int)));
diff --git a/lib/widgets/propeditor/pcombobox.cpp b/lib/widgets/propeditor/pcombobox.cpp
index fa21678b..7f0d242e 100644
--- a/lib/widgets/propeditor/pcombobox.cpp
+++ b/lib/widgets/propeditor/pcombobox.cpp
@@ -40,7 +40,7 @@ void PComboBox::init(bool rw)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQComboBox(rw, this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
fillBox();
diff --git a/lib/widgets/propeditor/pdateedit.cpp b/lib/widgets/propeditor/pdateedit.cpp
index 64bbde18..ed83dbb2 100644
--- a/lib/widgets/propeditor/pdateedit.cpp
+++ b/lib/widgets/propeditor/pdateedit.cpp
@@ -30,7 +30,7 @@ PDateEdit::PDateEdit(MultiProperty* property, TQWidget* parent, const char* name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQDateEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(const TQDate&)), this, TQT_SLOT(updateProperty(const TQDate&)));
diff --git a/lib/widgets/propeditor/pdatetimeedit.cpp b/lib/widgets/propeditor/pdatetimeedit.cpp
index 59df2440..3b8993d3 100644
--- a/lib/widgets/propeditor/pdatetimeedit.cpp
+++ b/lib/widgets/propeditor/pdatetimeedit.cpp
@@ -29,7 +29,7 @@ PDateTimeEdit::PDateTimeEdit(MultiProperty* property, TQWidget* parent, const ch
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQDateTimeEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(const TQDateTime&)), this, TQT_SLOT(updateProperty(const TQDateTime&)));
diff --git a/lib/widgets/propeditor/pdoublenuminput.cpp b/lib/widgets/propeditor/pdoublenuminput.cpp
index e48475de..753af410 100644
--- a/lib/widgets/propeditor/pdoublenuminput.cpp
+++ b/lib/widgets/propeditor/pdoublenuminput.cpp
@@ -43,7 +43,7 @@ PDoubleNumInput::PDoubleNumInput(MultiProperty *property, TQWidget *parent, cons
m_edit = new TQFloatInput(-999999, 999999, 0.01, 2, this );
connect(m_edit, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(updateProperty(int)));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
/* m_edit->setMinValue(-999999999);
m_edit->setMaxValue(+999999999);
m_edit->setPrecision(2);*/
diff --git a/lib/widgets/propeditor/pfontbutton.cpp b/lib/widgets/propeditor/pfontbutton.cpp
index e54e401f..82a96e9c 100644
--- a/lib/widgets/propeditor/pfontbutton.cpp
+++ b/lib/widgets/propeditor/pfontbutton.cpp
@@ -38,7 +38,7 @@ PFontButton::PFontButton(MultiProperty* property, TQWidget* parent, const char*
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KFontRequester(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
#ifndef PURE_QT
m_edit->button()->setText(i18n("..."));
#endif
diff --git a/lib/widgets/propeditor/pfontcombo.cpp b/lib/widgets/propeditor/pfontcombo.cpp
index 51b44e8c..8b0ee7a7 100644
--- a/lib/widgets/propeditor/pfontcombo.cpp
+++ b/lib/widgets/propeditor/pfontcombo.cpp
@@ -38,7 +38,7 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KFontCombo(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
/*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
diff --git a/lib/widgets/propeditor/plineedit.cpp b/lib/widgets/propeditor/plineedit.cpp
index 2c4fabc9..f5e1ecb0 100644
--- a/lib/widgets/propeditor/plineedit.cpp
+++ b/lib/widgets/propeditor/plineedit.cpp
@@ -29,7 +29,7 @@ PLineEdit::PLineEdit(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateProperty(const TQString&)));
diff --git a/lib/widgets/propeditor/plinestyleedit.cpp b/lib/widgets/propeditor/plinestyleedit.cpp
index a47dc614..996b1d0e 100644
--- a/lib/widgets/propeditor/plinestyleedit.cpp
+++ b/lib/widgets/propeditor/plinestyleedit.cpp
@@ -131,7 +131,7 @@ PLineStyleEdit::PLineStyleEdit(MultiProperty* property, TQWidget* parent, const
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQComboBox(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->insertItem(TQPixmap(nopen));
diff --git a/lib/widgets/propeditor/ppixmapedit.cpp b/lib/widgets/propeditor/ppixmapedit.cpp
index 20f943e8..bd8af048 100644
--- a/lib/widgets/propeditor/ppixmapedit.cpp
+++ b/lib/widgets/propeditor/ppixmapedit.cpp
@@ -46,7 +46,7 @@ PPixmapEdit::PPixmapEdit(MultiProperty* property, TQWidget* parent, const char*
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQLabel(this);
- m_edit->tqsetAlignment(TQt::AlignTop);
+ m_edit->setAlignment(TQt::AlignTop);
m_edit->resize(width(), height()-1);
m_edit->setBackgroundMode(TQt::PaletteBase);
m_edit->installEventFilter(this);
@@ -54,7 +54,7 @@ PPixmapEdit::PPixmapEdit(MultiProperty* property, TQWidget* parent, const char*
m_button = new TQPushButton(i18n("..."), this);
m_button->resize(height(), height()-8);
m_button->move(width() - m_button->width() -1, 0);
- m_button->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Fixed);
+ m_button->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Fixed);
l->addWidget(m_edit);
l->addWidget(m_button);
m_popup = new TQLabel(0, 0, TQt::WStyle_NoBorder|TQt::WX11BypassWM|WStyle_StaysOnTop);
diff --git a/lib/widgets/propeditor/ppointedit.cpp b/lib/widgets/propeditor/ppointedit.cpp
index 4e85d214..64a823a9 100644
--- a/lib/widgets/propeditor/ppointedit.cpp
+++ b/lib/widgets/propeditor/ppointedit.cpp
@@ -29,7 +29,7 @@ PPointEdit::PPointEdit(MultiProperty* property, TQWidget* parent, const char* na
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
diff --git a/lib/widgets/propeditor/prectedit.cpp b/lib/widgets/propeditor/prectedit.cpp
index d7a5fa01..dbc35ae5 100644
--- a/lib/widgets/propeditor/prectedit.cpp
+++ b/lib/widgets/propeditor/prectedit.cpp
@@ -29,7 +29,7 @@ PRectEdit::PRectEdit(MultiProperty* property, TQWidget* parent, const char* name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
diff --git a/lib/widgets/propeditor/propertyeditor.cpp b/lib/widgets/propeditor/propertyeditor.cpp
index ed7b81f2..4c5c8b16 100644
--- a/lib/widgets/propeditor/propertyeditor.cpp
+++ b/lib/widgets/propeditor/propertyeditor.cpp
@@ -196,7 +196,7 @@ PropertyEditor::PropertyEditor(TQWidget *parent, const char *name)
#else
m_undoButton->setPixmap( TQPixmap("undo.xpm") );
#endif
- m_undoButton->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ m_undoButton->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
m_undoButton->resize(m_undoButton->height(), m_undoButton->height());
m_undoButton->hide();
connect(m_undoButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(undo()));
@@ -360,11 +360,11 @@ void PropertyEditor::showEditor(PropertyItem *item)
void PropertyEditor::placeEditor(PropertyItem *item)
{
- TQRect r = tqitemRect(item);
+ TQRect r = itemRect(item);
if (!r.size().isValid())
{
ensureItemVisible(item);
- r = tqitemRect(item);
+ r = itemRect(item);
}
r.setX(header()->sectionPos(1));
@@ -447,7 +447,7 @@ Machine *PropertyEditor::machine(MultiProperty *property)
m_registeredForType[name] = PropertyMachineFactory::getInstance()->machineForProperty(property);
connect(m_registeredForType[name]->propertyEditor, TQT_SIGNAL(propertyChanged(MultiProperty*, const TQVariant&)),
this, TQT_SLOT(propertyChanged(MultiProperty*, const TQVariant&)));
- m_registeredForType[name]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->tqchildrenRect().topLeft());
+ m_registeredForType[name]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->childrenRect().topLeft());
m_registeredForType[name]->propertyEditor->hide();
}
return m_registeredForType[name];
diff --git a/lib/widgets/propeditor/psizeedit.cpp b/lib/widgets/propeditor/psizeedit.cpp
index 5558c3f3..c4d28402 100644
--- a/lib/widgets/propeditor/psizeedit.cpp
+++ b/lib/widgets/propeditor/psizeedit.cpp
@@ -30,7 +30,7 @@ PSizeEdit::PSizeEdit(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
diff --git a/lib/widgets/propeditor/psizepolicyedit.cpp b/lib/widgets/propeditor/psizepolicyedit.cpp
index 94847d2a..d9ec7869 100644
--- a/lib/widgets/propeditor/psizepolicyedit.cpp
+++ b/lib/widgets/propeditor/psizepolicyedit.cpp
@@ -31,7 +31,7 @@ PSizePolicyEdit::PSizePolicyEdit(MultiProperty* property, const TQMap<TQString,
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
diff --git a/lib/widgets/propeditor/pspinbox.cpp b/lib/widgets/propeditor/pspinbox.cpp
index e9c25325..755041c1 100644
--- a/lib/widgets/propeditor/pspinbox.cpp
+++ b/lib/widgets/propeditor/pspinbox.cpp
@@ -31,7 +31,7 @@ PSpinBox::PSpinBox(MultiProperty *property, TQWidget *parent, const char *name)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQSpinBox(INT_MIN, INT_MAX, 1, this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(updateProperty(int)));
diff --git a/lib/widgets/propeditor/pstringlistedit.cpp b/lib/widgets/propeditor/pstringlistedit.cpp
index fda16a8b..b6f4b74e 100644
--- a/lib/widgets/propeditor/pstringlistedit.cpp
+++ b/lib/widgets/propeditor/pstringlistedit.cpp
@@ -43,10 +43,10 @@ PStringListEdit::PStringListEdit(MultiProperty *property, TQWidget *parent, cons
edit = new KLineEdit(this);
edit->setReadOnly(true);
- edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(edit);
pbSelect = new TQPushButton("...", this);
- pbSelect->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ pbSelect->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
l->addWidget(pbSelect);
connect(pbSelect, TQT_SIGNAL(clicked()), this, TQT_SLOT(showEditor()));
diff --git a/lib/widgets/propeditor/psymbolcombo.cpp b/lib/widgets/propeditor/psymbolcombo.cpp
index 7e79945a..6116ca8c 100644
--- a/lib/widgets/propeditor/psymbolcombo.cpp
+++ b/lib/widgets/propeditor/psymbolcombo.cpp
@@ -40,11 +40,11 @@ PSymbolCombo::PSymbolCombo(MultiProperty *property, TQWidget *parent, const char
{
l = new TQHBoxLayout(this);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
m_edit->setMaxLength(1);
l->addWidget(m_edit);
m_select = new TQPushButton("...", this);
- m_select->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ m_select->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
l->addWidget(m_select);
#ifdef PURE_QT
diff --git a/lib/widgets/propeditor/purledit.cpp b/lib/widgets/propeditor/purledit.cpp
index df8316cd..047c9997 100644
--- a/lib/widgets/propeditor/purledit.cpp
+++ b/lib/widgets/propeditor/purledit.cpp
@@ -47,7 +47,7 @@ PUrlEdit::PUrlEdit(Mode mode, MultiProperty* property, TQWidget* parent, const c
m_mode = mode;
connect( m_select, TQT_SIGNAL(clicked()),this,TQT_SLOT(select()));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
}
TQVariant PUrlEdit::value() const
diff --git a/lib/widgets/propeditor/pyesnobutton.cpp b/lib/widgets/propeditor/pyesnobutton.cpp
index 614b751b..308570be 100644
--- a/lib/widgets/propeditor/pyesnobutton.cpp
+++ b/lib/widgets/propeditor/pyesnobutton.cpp
@@ -37,7 +37,7 @@ PYesNoButton::PYesNoButton(MultiProperty* property, TQWidget* parent, const char
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQPushButton(this);
m_edit->setToggleButton(true);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(updateProperty(bool)));
diff --git a/lib/widgets/propeditor/qeditlistbox.cpp b/lib/widgets/propeditor/qeditlistbox.cpp
index fda5a006..ad3ab6c4 100644
--- a/lib/widgets/propeditor/qeditlistbox.cpp
+++ b/lib/widgets/propeditor/qeditlistbox.cpp
@@ -92,7 +92,7 @@ void QEditListBox::init( bool checkAtEntering, int buttons,
servNewButton = servRemoveButton = servUpButton = servDownButton = 0L;
- tqsetSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
+ setSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
TQSizePolicy::MinimumExpanding));
TQWidget * gb = this;
diff --git a/lib/widgets/qcomboview.cpp b/lib/widgets/qcomboview.cpp
index 2dcfb9f3..700344de 100644
--- a/lib/widgets/qcomboview.cpp
+++ b/lib/widgets/qcomboview.cpp
@@ -39,7 +39,7 @@ public:
QComboViewData( QComboView *cb ): current(0), lView( 0 ), combo( cb )
{
duplicatesEnabled = TRUE;
- cb->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed ) );
+ cb->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed ) );
}
inline TQListView * listView() { return lView; }
@@ -68,7 +68,7 @@ public:
TQLineEdit * ed; // /bin/ed rules!
TQTimer *completionTimer;
- TQSize tqsizeHint;
+ TQSize sizeHint;
private:
bool usinglView;
@@ -81,7 +81,7 @@ void QComboViewData::updateLinedGeometry()
{
if ( !ed || !combo )
return;
- TQRect r = TQStyle::tqvisualRect( combo->tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, combo,
+ TQRect r = TQStyle::visualRect( combo->tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, combo,
TQStyle::SC_ComboBoxEditField), combo );
// qWarning("updateLinedGeometry(): currentItem is %d", combo->currentItem() == 0 ? 0 : 1);
@@ -204,7 +204,7 @@ void QComboView::clear()
d->current = 0;
if ( d->ed ) {
- d->ed->setText( TQString::tqfromLatin1("") );
+ d->ed->setText( TQString::fromLatin1("") );
d->updateLinedGeometry();
}
currentChanged();
@@ -272,10 +272,10 @@ void QComboView::setAutoResize( bool enable )
the contents change dynamically. To tqinvalidate the cached value
call setFont().
*/
-TQSize QComboView::tqsizeHint() const
+TQSize QComboView::sizeHint() const
{
- if ( isVisible() && d->tqsizeHint.isValid() )
- return d->tqsizeHint;
+ if ( isVisible() && d->sizeHint.isValid() )
+ return d->sizeHint;
constPolish();
// int i, w;
@@ -290,10 +290,10 @@ TQSize QComboView::tqsizeHint() const
maxW = w;
}
*/
- d->tqsizeHint = (tqstyle().tqsizeFromContents(TQStyle::CT_ComboBox, this,
+ d->sizeHint = (tqstyle().tqsizeFromContents(TQStyle::CT_ComboBox, this,
TQSize(maxW, maxH)).expandedTo(TQApplication::globalStrut()));
- return d->tqsizeHint;
+ return d->sizeHint;
}
@@ -385,7 +385,7 @@ void QComboView::setPalette( const TQPalette &palette )
void QComboView::setFont( const TQFont &font )
{
- d->tqsizeHint = TQSize(); // tqinvalidate size hint
+ d->sizeHint = TQSize(); // tqinvalidate size hint
TQWidget::setFont( font );
d->listView()->setFont( font );
if (d->ed)
@@ -412,7 +412,7 @@ void QComboView::resizeEvent( TQResizeEvent * e )
void QComboView::paintEvent( TQPaintEvent * )
{
TQPainter p( this );
- const TQColorGroup & g = tqcolorGroup();
+ const TQColorGroup & g = colorGroup();
p.setPen(g.text());
TQStyle::SFlags flags = TQStyle::Style_Default;
@@ -428,7 +428,7 @@ void QComboView::paintEvent( TQPaintEvent * )
}
// bool reverse = TQApplication::reverseLayout();
- tqstyle().tqdrawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
+ tqstyle().drawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
flags, TQStyle::SC_All,
(d->arrowDown ?
TQStyle::SC_ComboBoxArrow :
@@ -436,7 +436,7 @@ void QComboView::paintEvent( TQPaintEvent * )
TQRect re = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxEditField );
- re = TQStyle::tqvisualRect(re, this);
+ re = TQStyle::visualRect(re, this);
p.setClipRect( re );
if ( !d->ed ) {
@@ -445,14 +445,14 @@ void QComboView::paintEvent( TQPaintEvent * )
// we calculate the TQListBoxTexts height (ignoring strut)
int itemh = d->listView()->fontMetrics().lineSpacing() + 2;
p.translate( re.x(), re.y() + (re.height() - itemh)/2 );
- item->paintCell( &p, d->listView()->tqcolorGroup(), 0, width(), AlignLeft | AlignVCenter );
+ item->paintCell( &p, d->listView()->colorGroup(), 0, width(), AlignLeft | AlignVCenter );
}
} else if ( d->listView() && d->listView()->currentItem( ) && d->current ) {
TQListViewItem * item = d->current ;
const TQPixmap *pix = item->pixmap(0);
if ( pix ) {
p.fillRect( re.x(), re.y(), pix->width() + 4, re.height(),
- tqcolorGroup().brush( TQColorGroup::Base ) );
+ colorGroup().brush( TQColorGroup::Base ) );
p.drawPixmap( re.x() + 2, re.y() +
( re.height() - pix->height() ) / 2, *pix );
}
@@ -474,7 +474,7 @@ void QComboView::mousePressEvent( TQMouseEvent *e )
}
TQRect arrowRect = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
// Correction for motif style, where arrow is smaller
// and thus has a rect that doesn't fit the button.
@@ -700,12 +700,12 @@ static int listHeight( TQListView *l, int /*sl*/ )
prefH = ch * l->firstChild()->height();
}
else
- prefH = l->tqsizeHint().height();
+ prefH = l->sizeHint().height();
if (l->header()->isVisible())
- prefH += l->header()->tqsizeHint().height();
+ prefH += l->header()->sizeHint().height();
-// return prefH < l->tqsizeHint().height() ? prefH : l->tqsizeHint().height();
+// return prefH < l->sizeHint().height() ? prefH : l->sizeHint().height();
return prefH+2;
}
@@ -727,7 +727,7 @@ void QComboView::popup()
lb->installEventFilter( this );
lb->viewport()->installEventFilter( this );
d->mouseWasInsidePopup = FALSE;
-// int w = lb->variableWidth() ? lb->tqsizeHint().width() : width();
+// int w = lb->variableWidth() ? lb->sizeHint().width() : width();
int w = width();
int h = listHeight( lb, d->sizeLimit );
TQRect screen = TQApplication::desktop()->availableGeometry( const_cast<QComboView*>(this) );
@@ -790,7 +790,7 @@ void QComboView::updateMask()
{
TQPainter p( &bm, this );
- tqstyle().tqdrawComplexControlMask(TQStyle::CC_ComboBox, &p, this, rect());
+ tqstyle().drawComplexControlMask(TQStyle::CC_ComboBox, &p, this, rect());
}
setMask( bm );
@@ -904,7 +904,7 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
TQRect arrowRect =
tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
if ( arrowRect.contains( comboPos ) ) {
if ( !d->arrowDown ) {
d->arrowDown = TRUE;
@@ -918,7 +918,7 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
}
}
} else if ((e->state() & ( Qt::RightButton | Qt::LeftButton | Qt::MidButton ) ) == 0 &&
- tqstyle().tqstyleHint(TQStyle::SH_ComboBox_ListMouseTracking, this)) {
+ tqstyle().styleHint(TQStyle::SH_ComboBox_ListMouseTracking, this)) {
// qWarning("event filter:: emu");
TQWidget *mouseW = TQApplication::widgetAt( e->globalPos(), TRUE );
// if ( mouseW == d->listView()->viewport() ) { //###
@@ -1333,7 +1333,7 @@ bool QComboView::autoCompletion() const
*/
void QComboView::styleChange( TQStyle& s )
{
- d->tqsizeHint = TQSize(); // tqinvalidate size hint...
+ d->sizeHint = TQSize(); // tqinvalidate size hint...
if ( d->ed )
d->updateLinedGeometry();
TQWidget::styleChange( s );
diff --git a/lib/widgets/qcomboview.h b/lib/widgets/qcomboview.h
index ecfa8ee2..35eef4f1 100644
--- a/lib/widgets/qcomboview.h
+++ b/lib/widgets/qcomboview.h
@@ -68,7 +68,7 @@ public:
bool autoResize() const;
virtual void setAutoResize( bool );
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
void setPalette( const TQPalette & );
void setFont( const TQFont & );
diff --git a/lib/widgets/processwidget.cpp b/lib/widgets/processwidget.cpp
index 1b4cb3ab..1566a3e7 100644
--- a/lib/widgets/processwidget.cpp
+++ b/lib/widgets/processwidget.cpp
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
}
-TQSize ProcessWidget::tqminimumSizeHint() const
+TQSize ProcessWidget::minimumSizeHint() const
{
// I'm not sure about this, but when I don't use override tqminimumSizeHint(),
// the initial size in clearly too small
- return TQSize( TQListBox::tqsizeHint().width(),
+ return TQSize( TQListBox::sizeHint().width(),
(fontMetrics().lineSpacing()+2)*4 );
}
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
{
- // I'm not sure about this, but when I don't use override tqminimumSizeHint(),
+ // I'm not sure about this, but when I don't use override minimumSizeHint(),
// the initial size in clearly too small